yakumo.neutron.v2.vpn.service

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module service |
[hide private]
[frames] | no frames]

# Module service

source code

Resource class and its manager for VPN services in Networking V2 API

Classes | [hide private]
| Resource Resource class for VPN services in Networking V2 API
| Manager Manager class for VPN services in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.vpn``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('router', 'router_id', mapper.Resou
      rce('neutron.router')), ('subnet', 'subnet_id', mapper.Resource('neutr
      on.subnet')), ('project', 'tenant_id', mapper.Resource('project')), ('
      is_enabled', 'admin_state_up', mapper.Noop), ('status', 'status', mapp
      er.Noop),]